@@ -7,12 +7,13 @@ from __future__ import annotations
 import asyncio
 import time
 import logging
-from typing import Union, cast, TYPE_CHECKING
+from typing import Any, Callable, Dict, List, Optional, Union, cast, TYPE_CHECKING
 
 from ..._pyamqp import constants, error as errors
 from ..._pyamqp.aio import AMQPClientAsync, SendClientAsync, ReceiveClientAsync
 from ..._pyamqp.aio._authentication_async import JWTTokenAuthAsync
 from ..._pyamqp.aio._connection_async import Connection as ConnectionAsync
+from ..._pyamqp.endpoints import Source
 
 from ._base_async import AmqpTransportAsync
 from ..._transport._pyamqp_transport import PyamqpTransport
@@ -21,7 +22,7 @@ from ...exceptions import (
     EventDataSendError,
     OperationTimeoutError
 )
-from ..._common import EventData
+
 
 if TYPE_CHECKING:
     from .._client_base_async import ClientBaseAsync, ConsumerProducerMixin
@@ -36,18 +37,31 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
     """
 
     @staticmethod
-    async def create_connection_async(**kwargs) -> ConnectionAsync:
+    async def create_connection_async(# pylint:disable=unused-argument
+        *,
+        endpoint: str,
+        auth: JWTTokenAuthAsync,
+        container_id: Optional[str] = None,
+        max_frame_size: int,
+        channel_max: int,
+        idle_timeout: float,
+        properties: Optional[Dict[str, Any]] = None,
+        remote_idle_timeout_empty_frame_send_ratio: float,
+        error_policy: Any,
+        debug: bool,
+        encoding: str,
+        **kwargs: Any
+    ) -> ConnectionAsync:
         """
         Creates and returns the pyamqp Connection object.
-        :keyword str host: The hostname, used by pyamqp.
-        :keyword ~pyamqp.aio._authentication_async.JWTTokenAuthAsync auth: The auth, used by pyamqp.
         :keyword str endpoint: The endpoint, used by pyamqp.
+        :keyword ~pyamqp.aio._authentication_async.JWTTokenAuthAsync auth: The auth, used by pyamqp.
         :keyword str container_id: Required.
         :keyword int max_frame_size: Required.
         :keyword int channel_max: Required.
-        :keyword int idle_timeout: Required.
-        :keyword Dict properties: Required.
-        :keyword int remote_idle_timeout_empty_frame_send_ratio: Required.
+        :keyword float idle_timeout: Required.
+        :keyword dict[str, Any] or None properties: Required.
+        :keyword float remote_idle_timeout_empty_frame_send_ratio: Required.
         :keyword error_policy: Required.
         :keyword bool debug: Required.
         :keyword str encoding: Required.
@@ -55,11 +69,18 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
         :return: The created ConnectionAsync.
         :rtype: ~pyamqp.aio.Connection
         """
-        endpoint = kwargs.pop("endpoint")
-        host = kwargs.pop("host")  # pylint:disable=unused-variable
-        auth = kwargs.pop("auth")  # pylint:disable=unused-variable
-        network_trace = kwargs.pop("debug")
-        return ConnectionAsync(endpoint, network_trace=network_trace, **kwargs)
+        network_trace = debug
+        return ConnectionAsync(
+            endpoint,
+            container_id=container_id,
+            max_frame_size=max_frame_size,
+            channel_max=channel_max,
+            idle_timeout=idle_timeout,
+            properties=properties,
+            idle_timeout_empty_frame_send_ratio=remote_idle_timeout_empty_frame_send_ratio,
+            network_trace=network_trace,
+            **kwargs
+        )
 
     @staticmethod
     async def close_connection_async(connection):
@@ -70,7 +91,20 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
         await connection.close()
 
     @staticmethod
-    def create_send_client(*, config, **kwargs):  # pylint:disable=unused-argument
+    def create_send_client(# pylint: disable=unused-argument
+        *,
+        config,
+        target: str,
+        auth: JWTTokenAuthAsync, # type: ignore
+        idle_timeout: int,
+        network_trace: bool,
+        retry_policy: Any,
+        keep_alive_interval: int,
+        client_name: str,
+        link_properties: Optional[Dict[str, Any]],
+        properties: Optional[Dict[str, Any]] = None,
+        **kwargs: Any
+    ):
         """
         Creates and returns the pyamqp SendClient.
         :keyword ~azure.eventhub._configuration.Configuration config: The configuration.
@@ -83,12 +117,11 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
         :keyword keep_alive_interval: Required.
         :keyword str client_name: Required.
         :keyword dict link_properties: Required.
-        :keyword properties: Required.
+        :keyword dict[str, Any] or None properties: Required.
 
         :return: The created SendClientAsync.
         :rtype: ~pyamqp.aio.SendClientAsync
         """
-        target = kwargs.pop("target")
         # TODO: extra passed in to pyamqp, but not used. should be used?
         msg_timeout = kwargs.pop("msg_timeout")  # pylint: disable=unused-variable  # TODO: not used by pyamqp?
 
@@ -100,6 +133,15 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
             transport_type=config.transport_type,
             http_proxy=config.http_proxy,
             socket_timeout=config.socket_timeout,
+            auth=auth,
+            idle_timeout=idle_timeout,
+            network_trace=network_trace,
+            retry_policy=retry_policy,
+            keep_alive_interval=keep_alive_interval,
+            link_properties=link_properties,
+            properties=properties,
+            client_name=client_name,
+            use_tls=config.use_tls,
             **kwargs,
         )
 
@@ -123,33 +165,47 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
             raise OperationTimeoutError(message=str(exc), details=exc) from exc
 
     @staticmethod
-    def create_receive_client(*, config, **kwargs):  # pylint:disable=unused-argument
+    def create_receive_client(
+        *,
+        config,
+        source: Source,
+        auth: JWTTokenAuthAsync, # type: ignore
+        idle_timeout: int,
+        network_trace: bool,
+        retry_policy: Any,
+        client_name: str,
+        link_properties: Dict[bytes, Any],
+        properties: Optional[Dict[str, Any]] = None,
+        link_credit: int,
+        keep_alive_interval: int,
+        desired_capabilities: Optional[List[bytes]] = None,
+        streaming_receive: bool,
+        message_received_callback: Callable,
+        timeout: float,
+        **kwargs
+    ):
         """
         Creates and returns the receive client.
         :keyword ~azure.eventhub._configuration.Configuration config: The configuration.
 
-        :keyword str source: Required. The source.
-        :keyword str offset: Required.
-        :keyword str offset_inclusive: Required.
+        :keyword Source source: Required. The source.
         :keyword ~pyamqp.aio._authentication_async.JWTTokenAuthAsync auth: Required.
         :keyword int idle_timeout: Required.
         :keyword network_trace: Required.
         :keyword retry_policy: Required.
         :keyword str client_name: Required.
         :keyword dict link_properties: Required.
-        :keyword properties: Required.
+        :keyword dict[str, Any] or None properties: Required.
         :keyword link_credit: Required. The prefetch.
         :keyword keep_alive_interval: Required.
-        :keyword desired_capabilities: Required.
+        :keyword list[bytes] or None desired_capabilities: Required.
         :keyword streaming_receive: Required.
         :keyword message_received_callback: Required.
-        :keyword timeout: Required.
+        :keyword float timeout: Required.
 
         :return: The created ReceiveClientAsync.
         :rtype: ~pyamqp.aio.ReceiveClientAsync
         """
-
-        source = kwargs.pop("source")
         return ReceiveClientAsync(
             config.hostname,
             source,
@@ -159,6 +215,20 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
             custom_endpoint_address=config.custom_endpoint_address,
             connection_verify=config.connection_verify,
             socket_timeout=config.socket_timeout,
+            auth=auth,
+            idle_timeout=idle_timeout,
+            network_trace=network_trace,
+            retry_policy=retry_policy,
+            client_name=client_name,
+            link_properties=link_properties,
+            properties=properties,
+            link_credit=link_credit,
+            keep_alive_interval=keep_alive_interval,
+            desired_capabilities=desired_capabilities,
+            streaming_receive=streaming_receive,
+            message_received_callback=message_received_callback,
+            timeout=timeout,
+            use_tls=config.use_tls,
             **kwargs,
         )
 
@@ -253,7 +323,14 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
                     await asyncio.wait([t], timeout=1)
 
     @staticmethod
-    async def create_token_auth_async(auth_uri, get_token, token_type, config, **kwargs):
+    async def create_token_auth_async(
+        auth_uri: str,
+        get_token: Callable,
+        token_type: bytes,
+        config,
+        *,
+        update_token: bool,
+    ):
         """
         Creates the JWTTokenAuth.
         :param str auth_uri: The auth uri to pass to JWTTokenAuth.
@@ -269,7 +346,6 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
         :rtype: ~pyamqp.aio._authentication_async.JWTTokenAuthAsync
         """
         # TODO: figure out why we're passing all these args to pyamqp JWTTokenAuth, which aren't being used
-        update_token = kwargs.pop("update_token")  # pylint: disable=unused-variable
         if update_token:
             # update_token not actually needed by pyamqp
             # just using to detect wh
@@ -307,6 +383,7 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
             http_proxy=config.http_proxy,
             custom_endpoint_address=config.custom_endpoint_address,
             connection_verify=config.connection_verify,
+            use_tls=config.use_tls,
         )
 
     @staticmethod
@@ -321,7 +398,16 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
         return (await mgmt_auth.get_token()).token
 
     @staticmethod
-    async def mgmt_client_request_async(mgmt_client, mgmt_msg, **kwargs):
+    async def mgmt_client_request_async(
+        mgmt_client: AMQPClientAsync,
+        mgmt_msg: str,
+        *,
+        operation: bytes,
+        operation_type: bytes,
+        status_code_field: bytes,
+        description_fields: bytes,
+        **kwargs
+    ):
         """
         Send mgmt request.
         :param ~pyamqp.aio.AMQPClientAsync mgmt_client: Client to send request with.
@@ -334,10 +420,13 @@ class PyamqpTransportAsync(PyamqpTransport, AmqpTransportAsync):
         :return: The mgmt client.
         :rtype: ~pyamqp.aio.AMQPClientAsync
         """
-        operation_type = kwargs.pop("operation_type")
-        operation = kwargs.pop("operation")
         return await mgmt_client.mgmt_request_async(
-            mgmt_msg, operation=operation.decode(), operation_type=operation_type.decode(), **kwargs
+            mgmt_msg,
+            operation=operation.decode(),
+            operation_type=operation_type.decode(),
+            status_code_field=status_code_field,
+            description_fields=description_fields,
+            **kwargs
         )
 
     @staticmethod
