@@ -7,7 +7,7 @@ from __future__ import annotations
 import asyncio
 import time
 import logging
-from typing import Union, cast, TYPE_CHECKING, List, Optional, Any
+from typing import Callable, Dict, Union, cast, TYPE_CHECKING, List, Optional, Any
 
 try:
     from uamqp import (
@@ -18,6 +18,7 @@ try:
         utils,
         authentication,
         AMQPClientAsync,
+        Source,
         errors,
     )
     from uamqp.async_ops import ConnectionAsync
@@ -52,18 +53,31 @@ if uamqp_installed:
         """
 
         @staticmethod
-        async def create_connection_async(**kwargs) -> ConnectionAsync:
+        async def create_connection_async( # pylint:disable=unused-argument
+            *,
+            endpoint: str,
+            auth: authentication.JWTTokenAuth,
+            container_id: Optional[str] = None,
+            max_frame_size: int,
+            channel_max: int,
+            idle_timeout: float,
+            properties: Optional[Dict[str, Any]] = None,
+            remote_idle_timeout_empty_frame_send_ratio: float,
+            error_policy: Any,
+            debug: bool,
+            encoding: str,
+            **kwargs: Any
+        ) -> ConnectionAsync:
             """
             Creates and returns the uamqp async Connection object.
-            :keyword str host: The hostname, used by uamqp.
-            :keyword ~uamqp.authentication.JWTTokenAsync auth: The auth, used by uamqp.
             :keyword str endpoint: The endpoint, used by pyamqp.
+            :keyword ~uamqp.authentication.JWTTokenAsync auth: The auth, used by uamqp.
             :keyword str container_id: Required.
             :keyword int max_frame_size: Required.
             :keyword int channel_max: Required.
-            :keyword int idle_timeout: Required.
-            :keyword Dict properties: Required.
-            :keyword int remote_idle_timeout_empty_frame_send_ratio: Required.
+            :keyword float idle_timeout: Required.
+            :keyword dict[str, Any] or None properties: Required.
+            :keyword float remote_idle_timeout_empty_frame_send_ratio: Required.
             :keyword error_policy: Required.
             :keyword bool debug: Required.
             :keyword str encoding: Required.
@@ -71,12 +85,17 @@ if uamqp_installed:
             :return: The connection.
             :rtype: ~uamqp.async_ops.ConnectionAsync
             """
-            endpoint = kwargs.pop("endpoint") # pylint:disable=unused-variable
-            host = kwargs.pop("host")
-            auth = kwargs.pop("auth")
             return ConnectionAsync(
-                host,
+                endpoint,
                 auth,
+                container_id=container_id,
+                max_frame_size=max_frame_size,
+                channel_max=channel_max,
+                idle_timeout=idle_timeout,
+                properties=properties,
+                remote_idle_timeout_empty_frame_send_ratio=remote_idle_timeout_empty_frame_send_ratio,
+                encoding=encoding,
+                debug=debug,
                 **kwargs
             )
 
@@ -89,7 +108,20 @@ if uamqp_installed:
             await connection.destroy_async()
 
         @staticmethod
-        def create_send_client(*, config, **kwargs): # pylint:disable=unused-argument
+        def create_send_client(# pylint: disable=unused-argument
+            *,
+            config,
+            target: str,
+            auth: authentication.JWTTokenAuth,
+            idle_timeout: int,
+            network_trace: bool,
+            retry_policy: Any,
+            keep_alive_interval: int,
+            client_name: str,
+            link_properties: Optional[Dict[str, Any]] = None,
+            properties: Optional[Dict[str, Any]] = None,
+            **kwargs: Any
+        ):
             """
             Creates and returns the uamqp SendClient.
             :keyword ~azure.eventhub._configuration.Configuration config: The configuration.
@@ -102,19 +134,21 @@ if uamqp_installed:
             :keyword keep_alive_interval: Required.
             :keyword str client_name: Required.
             :keyword dict link_properties: Required.
-            :keyword properties: Required.
+            :keyword dict[str, Any] or None properties: Required.
 
             :return: The send client.
             :rtype: ~uamqp.SendClientAsync
             """
-            target = kwargs.pop("target")
-            retry_policy = kwargs.pop("retry_policy")
-            network_trace = kwargs.pop("network_trace")
-
             return SendClientAsync(
                 target,
-                debug=network_trace,  # pylint:disable=protected-access
+                debug=network_trace,
                 error_policy=retry_policy,
+                keep_alive_interval=keep_alive_interval,
+                client_name=client_name,
+                properties=properties,
+                link_properties=link_properties,
+                idle_timeout=idle_timeout,
+                auth=auth,
                 **kwargs
             )
 
@@ -141,24 +175,40 @@ if uamqp_installed:
                     raise producer._condition
 
         @staticmethod
-        def create_receive_client(*, config, **kwargs): # pylint:disable=unused-argument
+        def create_receive_client(# pylint:disable=unused-argument
+            *,
+            config,
+            source: Source,
+            auth: authentication.JWTTokenAuth,
+            idle_timeout: int,
+            network_trace: bool,
+            retry_policy: Any,
+            client_name: str,
+            link_properties: Dict[bytes, Any],
+            properties: Optional[Dict[str, Any]] = None,
+            link_credit: int,
+            keep_alive_interval: int,
+            desired_capabilities: Optional[List[bytes]] = None,
+            streaming_receive: bool,
+            message_received_callback: Callable,
+            timeout: float,
+            **kwargs
+        ):
             """
             Creates and returns the receive client.
             :keyword ~azure.eventhub._configuration.Configuration config: The configuration.
 
-            :keyword str source: Required. The source.
-            :keyword str offset: Required.
-            :keyword str offset_inclusive: Required.
+            :keyword Source source: Required. The source.
             :keyword ~uamqp.authentication.JWTTokenAuth auth: Required.
             :keyword int idle_timeout: Required.
             :keyword network_trace: Required.
             :keyword retry_policy: Required.
             :keyword str client_name: Required.
             :keyword dict link_properties: Required.
-            :keyword properties: Required.
+            :keyword dict[str, Any] or None properties: Required.
             :keyword link_credit: Required. The prefetch.
             :keyword keep_alive_interval: Required.
-            :keyword desired_capabilities: Required.
+            :keyword list[bytes] or None desired_capabilities: Required.
             :keyword streaming_receive: Required.
             :keyword message_received_callback: Required.
             :keyword timeout: Required.
@@ -166,18 +216,11 @@ if uamqp_installed:
             :return: The receive client.
             :rtype: ~uamqp.ReceiveClientAsync
             """
-
-            source = kwargs.pop("source")
-            symbol_array = kwargs.pop("desired_capabilities")
+            symbol_array = desired_capabilities
             desired_capabilities = None
             if symbol_array:
                 symbol_array = [types.AMQPSymbol(symbol) for symbol in symbol_array]
                 desired_capabilities = utils.data_factory(types.AMQPArray(symbol_array))
-            retry_policy = kwargs.pop("retry_policy")
-            network_trace = kwargs.pop("network_trace")
-            link_credit = kwargs.pop("link_credit")
-            streaming_receive = kwargs.pop("streaming_receive")
-            message_received_callback = kwargs.pop("message_received_callback")
 
             client = ReceiveClientAsync(
                 source,
@@ -187,11 +230,18 @@ if uamqp_installed:
                 prefetch=link_credit,
                 receive_settle_mode=constants.ReceiverSettleMode.ReceiveAndDelete,
                 auto_complete=False,
+                client_name=client_name,
+                properties=properties,
+                link_properties=link_properties,
+                idle_timeout=idle_timeout,
+                auth=auth,
+                keep_alive_interval=keep_alive_interval,
+                timeout=timeout,
                 **kwargs
             )
             # pylint:disable=protected-access
             client._streaming_receive = streaming_receive
-            client._message_received_callback = (message_received_callback)
+            client._message_received_callback = message_received_callback
             return client
 
         @staticmethod
@@ -268,7 +318,14 @@ if uamqp_installed:
                     await consumer._on_event_received(None)
 
         @staticmethod
-        async def create_token_auth_async(auth_uri, get_token, token_type, config, **kwargs):
+        async def create_token_auth_async(
+            auth_uri: str,
+            get_token: Callable,
+            token_type: bytes,
+            config,
+            *,
+            update_token: bool,
+        ):
             """
             Creates the JWTTokenAuth.
             :param str auth_uri: The auth uri to pass to JWTTokenAuth.
@@ -283,7 +340,6 @@ if uamqp_installed:
             :return: A JWTTokenAsync instance.
             :rtype: ~uamqp.authentication.JWTTokenAsync
             """
-            update_token = kwargs.pop("update_token")
             refresh_window = 300
             if update_token:
                 refresh_window = 0
@@ -344,7 +400,16 @@ if uamqp_installed:
             await mgmt_client.open_async(connection=conn)
 
         @staticmethod
-        async def mgmt_client_request_async(mgmt_client: AMQPClientAsync, mgmt_msg: str, **kwargs: Any):
+        async def mgmt_client_request_async(
+            mgmt_client: AMQPClientAsync,
+            mgmt_msg: str,
+            *,
+            operation: bytes,
+            operation_type: bytes,
+            status_code_field: bytes,
+            description_fields: bytes,
+            **kwargs: Any
+        ):
             """
             Send mgmt request.
             :param ~uamqp.AMQPClient mgmt_client: Client to send request with.
@@ -357,17 +422,17 @@ if uamqp_installed:
             :return: Status code, description, response.
             :rtype: tuple
             """
-            operation_type = kwargs.pop("operation_type")
-            operation = kwargs.pop("operation")
             response = await mgmt_client.mgmt_request_async(
                 mgmt_msg,
                 operation,
                 op_type=operation_type,
+                status_code_field=status_code_field,
+                description_fields=description_fields,
                 **kwargs
             )
-            status_code = response.application_properties[kwargs.get("status_code_field")]
+            status_code = response.application_properties[status_code_field]
             description: Optional[Union[str, bytes]] = response.application_properties.get(
-                kwargs.get("description_fields")
+                description_fields
             )
             return status_code, description, response
 
